# Bugs & wishlist items

<small>(… a.k.a. "things to fix" and "things to add".)</small>

!!! abstract inline end "Legend: Formatting"
      - [scheduled for next release](index.md){: .scheduled-next }
      - [scheduled for some future release](index.md){: .scheduled }
      - [yet to be scheduled](index.md){: .unscheduled }

???+ bug "things to fix"
      - [remove-click][]{: .scheduled-next }

???+ wish "things to add"
      - [no-strict-compatibility-mode][]{: .scheduled }
      - [conventional-configurable-text-styling][]{: .unscheduled }
      - [other-derivation-schemes][]{: .unscheduled }

??? bug-success "things fixed"
      - [allow-all-unicode-passphrases][]{: .fixed }
      - [amend-vault-config][]{: .fixed }
      - [better-error-messages][]{: .fixed }
      - [concurrency-audit][]{: .fixed }
      - [concurrency-testing-in-test-suite][]{: .fixed }
      - [configuration-directory-must-exist][]{: .fixed }
      - [fail-gracefully-without-af-unix][]{: .fixed }
      - [falsy-vault-config-values][]{: .fixed }
      - [no-stdlib-module-names][]{: .fixed }
      - [one-time-key-override-fails][]{: .fixed }
      - [print-service-notes][]{: .fixed }
      - [remove-pageant-build-info-check][]{: .fixed }
      - [single-toplevel-module][]{: .fixed }
      - [test-filesystem-isolation][]{: .fixed }
      - [windows-ssh-agent-support][]{: .fixed }

??? wish-success "things added"

      - [export-vault-formats][]{: .fixed }
      - [exporter-script-as-subcommand][]{: .fixed }
      - [pretty-print-json][]{: .fixed }
      - [print-service-notes-above][]{: .fixed }
      - [report-build-flags-and-features][]{: .fixed }
      - [scheme-specific-cli-and-config][]{: .fixed }
      - [test-suite-isolated-ssh-agent][]{: .fixed }

  [allow-all-unicode-passphrases]: allow-all-unicode-passphrases.md
  [amend-vault-config]: amend-vault-config.md
  [better-error-messages]: better-error-messages.md
  [concurrency-audit]: concurrency-audit.md
  [concurrency-testing-in-test-suite]: concurrency-testing-in-test-suite.md
  [configuration-directory-must-exist]: configuration-directory-must-exist.md
  [conventional-configurable-text-styling]: conventional-configurable-text-styling.md
  [export-vault-formats]: export-vault-formats.md
  [exporter-script-as-subcommand]: exporter-script-as-subcommand.md
  [fail-gracefully-without-af-unix]: fail-gracefully-without-af-unix.md
  [falsy-vault-config-values]: falsy-vault-config-values.md
  [no-stdlib-module-names]: no-stdlib-module-names.md
  [no-strict-compatibility-mode]: no-strict-compatibility-mode.md
  [one-time-key-override-fails]: one-time-key-override-fails.md
  [other-derivation-schemes]: other-derivation-schemes.md
  [pretty-print-json]: pretty-print-json.md
  [print-service-notes]: print-service-notes.md
  [print-service-notes-above]: print-service-notes-above.md
  [remove-click]: remove-click.md
  [remove-pageant-build-info-check]: remove-pageant-build-info-check.md
  [report-build-flags-and-features]: report-build-flags-and-features.md
  [scheme-specific-cli-and-config]: scheme-specific-cli-and-config.md
  [single-toplevel-module]: single-toplevel-module.md
  [test-filesystem-isolation]: test-filesystem-isolation.md
  [test-suite-isolated-ssh-agent]: test-suite-isolated-ssh-agent.md
  [windows-ssh-agent-support]: windows-ssh-agent-support.md
